.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`io`
=================
.. automodule:: skimage.io

.. currentmodule:: skimage.io
.. autosummary::

   skimage.io.call_plugin
   skimage.io.concatenate_images
   skimage.io.find_available_plugins
   skimage.io.imread
   skimage.io.imread_collection
   skimage.io.imread_collection_wrapper
   skimage.io.imsave
   skimage.io.imshow
   skimage.io.imshow_collection
   skimage.io.load_sift
   skimage.io.load_surf
   skimage.io.plugin_info
   skimage.io.plugin_order
   skimage.io.pop
   skimage.io.push
   skimage.io.reset_plugins
   skimage.io.show
   skimage.io.use_plugin

   skimage.io.ImageCollection
   skimage.io.MultiImage

    skimage.io.collection
    skimage.io.manage_plugins
    skimage.io.sift
    skimage.io.util

call_plugin
-----------

.. autofunction:: skimage.io.call_plugin


.. include:: skimage.io.call_plugin.examples

concatenate_images
------------------

.. autofunction:: skimage.io.concatenate_images


.. include:: skimage.io.concatenate_images.examples

find_available_plugins
----------------------

.. autofunction:: skimage.io.find_available_plugins


.. include:: skimage.io.find_available_plugins.examples

imread
------

.. autofunction:: skimage.io.imread


.. include:: skimage.io.imread.examples

imread_collection
-----------------

.. autofunction:: skimage.io.imread_collection


.. include:: skimage.io.imread_collection.examples

imread_collection_wrapper
-------------------------

.. autofunction:: skimage.io.imread_collection_wrapper


.. include:: skimage.io.imread_collection_wrapper.examples

imsave
------

.. autofunction:: skimage.io.imsave


.. include:: skimage.io.imsave.examples

imshow
------

.. autofunction:: skimage.io.imshow


.. include:: skimage.io.imshow.examples

imshow_collection
-----------------

.. autofunction:: skimage.io.imshow_collection


.. include:: skimage.io.imshow_collection.examples

load_sift
---------

.. autofunction:: skimage.io.load_sift


.. include:: skimage.io.load_sift.examples

load_surf
---------

.. autofunction:: skimage.io.load_surf


.. include:: skimage.io.load_surf.examples

plugin_info
-----------

.. autofunction:: skimage.io.plugin_info


.. include:: skimage.io.plugin_info.examples

plugin_order
------------

.. autofunction:: skimage.io.plugin_order


.. include:: skimage.io.plugin_order.examples

pop
---

.. autofunction:: skimage.io.pop


.. include:: skimage.io.pop.examples

push
----

.. autofunction:: skimage.io.push


.. include:: skimage.io.push.examples

reset_plugins
-------------

.. autofunction:: skimage.io.reset_plugins


.. include:: skimage.io.reset_plugins.examples

show
----

.. autofunction:: skimage.io.show


.. include:: skimage.io.show.examples

use_plugin
----------

.. autofunction:: skimage.io.use_plugin


.. include:: skimage.io.use_plugin.examples


:class:`ImageCollection`
------------------------


.. autoclass:: ImageCollection
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.io.ImageCollection.examples


:class:`MultiImage`
-------------------


.. autoclass:: MultiImage
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.io.MultiImage.examples

